#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-FIpQlvjtBnI3V7EynKctW5
key:                  persistent-mysql-2.13.1.5-FIpQlvjtBnI3V7EynKctW5
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  dced17b57b645a2d2b1bdcb6532e9c66
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-FIpQlvjtBnI3V7EynKctW5
depends:
    aeson-2.2.2.0-DAWEUfqGTZl4JS91alOoes base-4.18.2.1
    blaze-builder-0.4.4.1-9lldmKNQnxDJ3FVwGSFUXH bytestring-0.11.5.3
    conduit-1.3.6.1-5Wps0pi1oaaLry3JJy7JDj containers-0.6.7
    monad-logger-0.3.42-HTjjb62hBM13WDs3uTlqIP
    mysql-0.2.1-HWHow6D6UI98YN5XuBBeMc
    mysql-simple-0.4.9-1QqC1qlAI3N7XwWKzNQaQl
    persistent-2.14.5.2-FDFSQJTxvpv4st0dNLm6e6
    resource-pool-0.2.3.2-9bQ5SwYy5J2CEcxOtdq53p
    resourcet-1.2.6-6VmvylmAyS7HrfWxVbJ0NO text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

